@@ -42,7 +42,7 @@ namespace LXQtPolicykit
 PolicykitAgent::PolicykitAgent(QObject *parent)
     : PolkitQt1::Agent::Listener(parent),
       m_inProgress(false),
-      m_gui(0),
+      m_gui(nullptr),
       m_infobox(nullptr)
 {
     PolkitQt1::UnixSessionSubject session(getpid());
@@ -51,14 +51,20 @@ PolicykitAgent::PolicykitAgent(QObject *parent)
 
 PolicykitAgent::~PolicykitAgent()
 {
-    if (m_gui)
+    if (m_gui != nullptr)
     {
         m_gui->blockSignals(true);
         m_gui->deleteLater();
     }
-    if(m_infobox) {
-      delete m_infobox;
-    }
+    delete m_infobox;
+    deleteSessions();
+}
+
+void PolicykitAgent::deleteSessions()
+{
+    for (auto i = m_SessionIdentity.begin(), i_e = m_SessionIdentity.end(); i != i_e; ++i)
+        delete i.key();
+    m_SessionIdentity.clear();
 }
 
 
@@ -72,16 +78,16 @@ void PolicykitAgent::initiateAuthentication(const QString &actionId,
 {
     if (m_inProgress)
     {
-        QMessageBox::information(0, tr("PolicyKit Information"), tr("Another authentication is in progress. Please try again later."));
+        QMessageBox::information(nullptr, tr("PolicyKit Information"), tr("Another authentication is in progress. Please try again later."));
         return;
     }
     m_inProgress = true;
-    m_SessionIdentity.clear();
+    deleteSessions();
 
-    if (m_gui)
+    if (m_gui != nullptr)
     {
         delete m_gui;
-        m_gui = 0;
+        m_gui = nullptr;
     }
     m_gui = new PolicykitAgentGUI(actionId, message, iconName, details, identities);
 
@@ -91,10 +97,10 @@ void PolicykitAgent::initiateAuthentication(const QString &actionId,
         session = new PolkitQt1::Agent::Session(i, cookie, result);
         Q_ASSERT(session);
         m_SessionIdentity[session] = i;
-        connect(session, SIGNAL(request(QString, bool)), this, SLOT(request(QString, bool)));
-        connect(session, SIGNAL(completed(bool)), this, SLOT(completed(bool)));
-        connect(session, SIGNAL(showError(QString)), this, SLOT(showError(QString)));
-        connect(session, SIGNAL(showInfo(QString)), this, SLOT(showInfo(QString)));
+        connect(session, &PolkitQt1::Agent::Session::request, this, &PolicykitAgent::request);
+        connect(session, &PolkitQt1::Agent::Session::completed, this, &PolicykitAgent::completed);
+        connect(session, &PolkitQt1::Agent::Session::showError, this, &PolicykitAgent::showError);
+        connect(session, &PolkitQt1::Agent::Session::showInfo, this, &PolicykitAgent::showInfo);
         session->initiate();
     }
 }
@@ -120,7 +126,7 @@ void PolicykitAgent::request(const QString &request, bool echo)
 
     PolkitQt1::Identity identity = m_SessionIdentity[session];
     m_gui->setPrompt(identity, request, echo);
-    connect(m_gui, &QDialog::finished, [this, session] (int result)
+    connect(m_gui, &QDialog::finished, this, [this, session] (int result)
     {
         if (result == QDialog::Accepted && m_gui->identity() == m_SessionIdentity[session].toString())
             session->setResponse(m_gui->response());
@@ -138,11 +144,11 @@ void PolicykitAgent::completed(bool gainedAuthorization)
     Q_ASSERT(session);
     Q_ASSERT(m_gui);
 
-    if (m_gui->identity() == m_SessionIdentity[session].toString())
+    if (m_inProgress && m_gui->identity() == m_SessionIdentity[session].toString())
     {
         if (!gainedAuthorization)
         {
-            QMessageBox::information(0, tr("Authorization Failed"), tr("Authorization failed for some reason"));
+            QMessageBox::information(nullptr, tr("Authorization Failed"), tr("Authorization failed for some reason"));
         }
 
         // Note: the setCompleted() must be called exacly once (as the
@@ -150,21 +156,20 @@ void PolicykitAgent::completed(bool gainedAuthorization)
         session->result()->setCompleted();
         m_inProgress = false;
     }
-    if (m_infobox){
+    if (m_infobox != nullptr){
       m_infobox->hide();
       delete m_infobox;
     }
-    delete session;
 }
 
 void PolicykitAgent::showError(const QString &text)
 {
-    QMessageBox::warning(0, tr("PolicyKit Error"), text);
+    QMessageBox::warning(nullptr, tr("PolicyKit Error"), text);
 }
 
 void PolicykitAgent::showInfo(const QString &text)
 {
-    m_infobox = new QMessageBox(0);
+    m_infobox = new QMessageBox(nullptr);
     m_infobox->setText(text);
     m_infobox->setWindowTitle(tr("PolicyKit Information"));
     m_infobox->setStandardButtons(QMessageBox::Ok);
