@@ -50,7 +50,7 @@ class PolicykitAgent : public PolkitQt1::Agent::Listener
 
 public:
     PolicykitAgent(QObject *parent = 0);
-    ~PolicykitAgent();
+    ~PolicykitAgent() override;
 
 public slots:
     void initiateAuthentication(const QString &actionId,
@@ -59,15 +59,18 @@ public slots:
                                 const PolkitQt1::Details &details,
                                 const QString &cookie,
                                 const PolkitQt1::Identity::List &identities,
-                                PolkitQt1::Agent::AsyncResult *result);
-    bool initiateAuthenticationFinish();
-    void cancelAuthentication();
+                                PolkitQt1::Agent::AsyncResult *result) override;
+    bool initiateAuthenticationFinish() override;
+    void cancelAuthentication() override;
 
     void request(const QString &request, bool echo);
     void completed(bool gainedAuthorization);
     void showError(const QString &text);
     void showInfo(const QString &text);
 
+protected:
+    void deleteSessions();
+
 private:
     bool m_inProgress;
     PolicykitAgentGUI * m_gui;
